# [![vinplots](/docs/images/vinplots.logo.svg)](https://github.com/mvinyard/vinplots/)

[![PyPI pyversions](https://img.shields.io/pypi/pyversions/vinplots.svg)](https://pypi.python.org/pypi/vinplots/)
[![PyPI version](https://badge.fury.io/py/vinplots.svg)](https://badge.fury.io/py/vinplots)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


[Michael Vinyard](https://github.com/mvinyard)'s python plotting assistant

### To install (Current release: [`v0.0.72`](https://github.com/mvinyard/vinplots/releases/tag/v0.0.60)):

```BASH
pip install vinplots
```

**To install the development version**:
```BASH
git clone https://github.com/mvinyard/vinplots.git; cd vinplots
pip install -e .
```

### Quickstart

```python

import vinplots

fig, axes = vinplots.quick_plot()
```

For more documentation, see: [here](https://vinplots.readthedocs.io/en/latest/index.html).
